//
//  StuffItService.m
//  StuffItService
//
//  Created by Alexandre Colucci on 28/03/10.
//  Copyright 2010 timac.org. All rights reserved.
//

#import "StuffItService.h"


@implementation StuffItService


// This function is called when you 'Stuff' one or multiple files.
// If multiple files are selected, one archive is made containing the files.
- (void)doStuff:(NSPasteboard *)pboard userData:(NSString *)userData error:(NSString **)error
{
	NSString *stuffToolPath = nil;
	if([[NSFileManager defaultManager] fileExistsAtPath:@"/usr/bin/stuff"])
	{
		// StuffIt Deluxe 2011
		stuffToolPath = @"/usr/bin/stuff";
	}
	else if([[NSFileManager defaultManager] fileExistsAtPath:@"/usr/local/bin/stuff"])
	{
		// StuffIt Deluxe 2010
		stuffToolPath = @"/usr/local/bin/stuff";
	}
	
	if(stuffToolPath == nil)
	{
		
		*error = NSLocalizedString(@"Error: StuffIt Deluxe appears to not be installed.", nil);
		return;
	}
	
	NSArray *files = [pboard propertyListForType:NSFilenamesPboardType];
	if(files != nil && [files count] > 0)
	{
		NSMutableArray *arguments = [[NSMutableArray alloc] init];
		
		NSUInteger fileIndex = 0;
		for(fileIndex = 0; fileIndex < [files count]; fileIndex++)
		{
			NSString *theFilePath = [files objectAtIndex:fileIndex];
			if(theFilePath != nil && [[NSFileManager defaultManager] fileExistsAtPath:theFilePath])
			{
				[arguments addObject:theFilePath];
			}
		}
		
		if(arguments != nil && [arguments count] > 0)
		{
			NSTask *task = [[NSTask alloc] init];
			[task setLaunchPath:stuffToolPath];
			[task setArguments:arguments];
			
			NSPipe *pipe;
			pipe = [NSPipe pipe];
			[task setStandardOutput: pipe];
			
			[task launch];
		}
		
		[arguments release];
	}
}

// This function is called when you 'UnStuff' one or multiple files.
- (void)doUnStuff:(NSPasteboard *)pboard userData:(NSString *)userData error:(NSString **)error
{
	NSString *stuffToolPath = nil;
	if([[NSFileManager defaultManager] fileExistsAtPath:@"/usr/bin/unstuff"])
	{
		// StuffIt Deluxe 2011
		stuffToolPath = @"/usr/bin/unstuff";
	}
	else if([[NSFileManager defaultManager] fileExistsAtPath:@"/usr/local/bin/unstuff"])
	{
		// StuffIt Deluxe 2010
		stuffToolPath = @"/usr/local/bin/unstuff";
	}
	
	if(stuffToolPath == nil)
	{
		*error = NSLocalizedString(@"Error: StuffIt Deluxe appears to not be installed.", nil);
		return;
	}
	
	NSArray *files = [pboard propertyListForType:NSFilenamesPboardType];
	if(files != nil && [files count] > 0)
	{
		NSUInteger fileIndex = 0;
		for(fileIndex = 0; fileIndex < [files count]; fileIndex++)
		{
			NSString *theFilePath = [files objectAtIndex:fileIndex];
			if(theFilePath != nil && [[NSFileManager defaultManager] fileExistsAtPath:theFilePath])
			{
				NSArray *arguments = [NSArray arrayWithObjects:theFilePath, nil];
				
				NSTask *task = [[NSTask alloc] init];
				[task setLaunchPath:stuffToolPath];
				[task setArguments:arguments];
				
				NSPipe *pipe;
				pipe = [NSPipe pipe];
				[task setStandardOutput: pipe];
				
				[task launch];
			}
		}
	}
}


@end
